==> odoo_19.1a1.20251211.zip: odoo-19.1a1.post20251211/odoo/addons/l10n_au/models/template_au.py <==
# Part of Odoo. See LICENSE file for full copyright and licensing details.
from odoo import models
from odoo.addons.account.models.chart_template import template


class AccountChartTemplate(models.AbstractModel):
    _inherit = 'account.chart.template'

    @template('au')
    def _get_au_template_data(self):
        return {
            'code_digits': '5',
            'property_account_receivable_id': 'au_11200',
            'property_stock_account_production_cost_id': 'au_11350',
            'property_account_payable_id': 'au_21200',
            'property_stock_valuation_account_id': 'au_11330',
        }

    @template('au', 'res.company')
    def _get_au_res_company(self):
        return {
            self.env.company.id: {
                'anglo_saxon_accounting': True,
                'account_fiscal_country_id': 'base.au',
                'bank_account_code_prefix': '1111',
                'cash_account_code_prefix': '1113',
                'transfer_account_code_prefix': '11170',
                'account_default_pos_receivable_account_id': 'au_11201',
                'income_currency_exchange_account_id': 'au_61640',
                'expense_currency_exchange_account_id': 'au_61630',
                'account_journal_early_pay_discount_loss_account_id': 'au_61610',
                'account_journal_early_pay_discount_gain_account_id': 'au_61620',
                'fiscalyear_last_month': '6',
                'fiscalyear_last_day': 30,
                'account_sale_tax_id': 'au_tax_sale_10',
                'account_purchase_tax_id': 'au_tax_purchase_10_service',
                'income_account_id': 'au_41110',
                'expense_account_id': 'au_51110',
                'account_stock_valuation_id': 'au_11310',
            },
        }

    @template('au', 'account.account')
    def _get_au_account_account(self):
        return {
            'au_11310': {
                'account_stock_variation_id': 'au_51110',
            },
        }

==> odoo_19.2a1.20260216.zip: odoo-19.2a1.post20260216/odoo/addons/l10n_au/models/template_au.py <==
# Part of Odoo. See LICENSE file for full copyright and licensing details.
from odoo import models
from odoo.addons.account.models.chart_template import template


class AccountChartTemplate(models.AbstractModel):
    _inherit = 'account.chart.template'

    @template('au')
    def _get_au_template_data(self):
        return {
            'code_digits': '5',
            'property_account_receivable_id': 'au_11200',
            'property_stock_account_production_cost_id': 'au_11350',
            'property_account_payable_id': 'au_21200',
            'property_stock_valuation_account_id': 'au_11330',
        }

    @template('au', 'res.company')
    def _get_au_res_company(self):
        return {
            self.env.company.id: {
                'anglo_saxon_accounting': True,
                'account_fiscal_country_id': 'base.au',
                'bank_account_code_prefix': '1111',
                'cash_account_code_prefix': '1113',
                'transfer_account_code_prefix': '11170',
                'account_default_pos_receivable_account_id': 'au_11201',
                'income_currency_exchange_account_id': 'au_61640',
                'expense_currency_exchange_account_id': 'au_61630',
                'account_journal_early_pay_discount_loss_account_id': 'au_61610',
                'account_journal_early_pay_discount_gain_account_id': 'au_61620',
                'fiscalyear_last_month': '6',
                'fiscalyear_last_day': 30,
                'account_sale_tax_id': 'au_tax_sale_10',
                'account_purchase_tax_id': 'au_tax_purchase_10_service',
                'income_account_id': 'au_41110',
                'expense_account_id': 'au_51110',
                'account_stock_valuation_id': 'au_11310',
            },
        }

    @template('au', 'account.account')
    def _get_au_account_account(self):
        return {
            'au_11310': {
                'account_stock_variation_id': 'au_51110',
            },
            'au_13120': {'asset_depreciation_account_id': 'au_13130', 'asset_expense_account_id': 'au_61500'},
            'au_13140': {'asset_depreciation_account_id': 'au_13150', 'asset_expense_account_id': 'au_61500'},
            'au_13160': {'asset_depreciation_account_id': 'au_13170', 'asset_expense_account_id': 'au_61500'},
            'au_13210': {'asset_depreciation_account_id': 'au_13220', 'asset_expense_account_id': 'au_61500'},
            'au_13310': {'asset_depreciation_account_id': 'au_13320', 'asset_expense_account_id': 'au_61500'},
            'au_13410': {'asset_depreciation_account_id': 'au_13420', 'asset_expense_account_id': 'au_61500'},
            'au_13430': {'asset_depreciation_account_id': 'au_13440', 'asset_expense_account_id': 'au_61500'},
            'au_13450': {'asset_depreciation_account_id': 'au_13460', 'asset_expense_account_id': 'au_61500'},
            'au_13470': {'asset_depreciation_account_id': 'au_13480', 'asset_expense_account_id': 'au_61500'},
        }
